<?php

namespace Myriad\SharePoint\Auth;

use Myriad\SharePoint\Contracts\TokenRetriever;
use Myriad\SharePoint\Models\Token\Token;
use GuzzleHttp\ClientInterface;
use Myriad\SharePoint\Contracts\Configuration;

class AzureADAuthenticator implements TokenRetriever {

  private $httpClient;
  private $clientId;
  private $clientSecret;
  private $resource;
  private $oauthUrl;
  private $scope;
  private $username;
  private $password;

  public function __construct(
    ClientInterface $httpClient,
    Configuration $config,
    $username,
    $password
  ) {
    $this->httpClient = $httpClient;
    $this->clientId = $config->getOAuth2ClientID();
    $this->clientSecret = $config->getOAuth2ClientSecret();
    $this->resource = "https://" . $config->getTenant() . '.sharepoint.com';
    $this->oauthUrl = $config->getOAuth2TokenUrl();
    $this->scope = $config->getOAuth2Scope();
    $this->username = $username;
    $this->password = $password;
  }

  /**
   * Retrieves an access token.
   *
   * @return Token
   */
  public function getAccessToken() {
    $result = $this->httpClient->post(
      $this->oauthUrl,
      [
        'body' => [
          'grant_type' => 'password',
          'username' => $this->username,
          'password' => $this->password,
          'client_id' => $this->clientId,
          'client_secret' => $this->clientSecret,
          'resource' => $this->resource,
          'scope' => $this->scope,
        ]
      ]
    );

    $data = json_decode($result->getBody(), true);

    return new Token(
      $data['access_token'],
      $data['refresh_token'],
      $data['not_before'],
      $data['expires_on'],
      ""
    );

  }

}
