<?php namespace Myriad\SharePoint\Auth\SharePointOnline;

/**
 * Class AuthForm knows how to parse the properties out of the claim form that are needed to
 * submit a claim.
 *
 * @author David Kanenwisher
 * @package Myriad\SharePoint\Auth
 */
class AuthForm {

  /**
   * @var \DomXPath The form required in order to request a claim.
   */
  private $htmlClaimForm;

  /**
   * Creates a new object.
   *
   * @param \DomXPath $htmlClaimForm The form required in order to request a claim.
   */
  public function __construct(\DomXPath $htmlClaimForm) {
    $this->htmlClaimForm = $htmlClaimForm;
  }

  /**
   * The action attribute of the form.
   *
   * @return string
   */
  public function getAction() {
    $form = $this->htmlClaimForm->query("//form")[0];

    return $form->getAttribute('action');
  }

  /**
   * Generates the body of an HTTP request from the contents of the from.
   *
   * @return array
   */
  public function getBody() {
    $form = $this->htmlClaimForm->query("//form")[0];
    $inputs = $this->htmlClaimForm->query('.//input', $form);

    $body = [];
    foreach ($inputs as $input) {
      if ($input->getAttribute('type') == 'hidden') {
        $body[$input->getAttribute('name')] = $input->getAttribute('value');
      }
    }

    # find the trust it target
    $event = $this->htmlClaimForm->query('//input[@accesskey="O"]')[0];
    $event->getAttribute('name');
    $body['__EVENTTARGET'] = $event->getAttribute('name');

    return $body;
  }
}