<?php namespace Myriad\SharePoint\Auth\SharePointOnline;

/**
 * Class BinarySecurityTokenParser Knows how to parse the binary security token returned by SharePointOnline.
 *
 * @author David Kanenwisher
 * @package Myriad\SharePoint\Auth\SharePointOnline
 */
class BinarySecurityTokenParser {

  /**
   * @var string The extSTSResponse from SharePointOnline.
   */
  private $extSTSResponse;

  /**
   * Creates a new object.
   *
   * @param string $extSTSResponse
   */
  public function __construct($extSTSResponse) {
    $this->extSTSResponse = $extSTSResponse;
  }

  /**
   * Parses the extSTSResponse for the token.
   *
   * @return string
   * @throws \Exception
   */
  public function parse() {
    $xml = new \DOMDocument();
    $xml->loadXML($this->extSTSResponse);
    $xpath = new \DOMXPath($xml);
    $xpath->registerNamespace('psf', "http://schemas.microsoft.com/Passport/SoapServices/SOAPFault");
    $errors = $xpath->query("//psf:internalerror");
    if ($errors->length > 0) {
      $info = $errors->item(0)->childNodes;
      throw new \Exception($info->item(1)->nodeValue, $info->item(0)->nodeValue);
    }
    $nodelist = $xpath->query("//wsse:BinarySecurityToken");
    foreach ($nodelist as $n) {
      $token = $n->nodeValue;
      break;
    }
    if (!isset($token)) {
      throw new \Exception("Unable to extract token from security token response");
    }

    return $token;
  }
}