<?php namespace Myriad\SharePoint\Auth\SharePointOnline;

use Myriad\SharePoint\Contracts;
use Myriad\SharePoint\Models\Token;

/**
 * Class SharePointOnlineOperations defines operations that have to be performed when performing SharePoint
 * authentication.
 *
 * @author David Kanenwisher
 * @package Myriad\SharePoint\Auth
 */
class Operations implements Contracts\Auth\SharePointOnline\Operations {

  /**
   * Returns an AuthForm.
   *
   * @param \DomXPath $htmlClaimForm The form required in order to request a claim.
   *
   * @return \Myriad\SharePoint\Auth\SharePointOnline\AuthForm
   */
  public function getAuthForm(\DomXPath $htmlClaimForm) {
    return new AuthForm($htmlClaimForm);
  }

  /**
   * Returns a CodeFinder.
   *
   * @param string $locationHeader The location header.
   *
   * @return \Myriad\SharePoint\Auth\SharePointOnline\CodeFinder
   */
  public function getCodeFinder($locationHeader) {
    return new CodeFinder($locationHeader);
  }

  /**
   * Returns a HtmlToXpath object.
   *
   * @param string $html The HTML string to convert to an XPath object.
   *
   * @return \Myriad\SharePoint\Auth\SharePointOnline\HtmlToXpath
   */
  public function getHtmlToXpath($html) {
    return new HtmlToXpath($html);
  }

  /**
   * Returns a RealmFinder.
   *
   * @param string $authenticationHeader The authentication header.
   *
   * @return RealmFinder
   */
  public function getRealmFinder($authenticationHeader) {
    return new RealmFinder($authenticationHeader);
  }

  /**
   * Returns a BinarySecurityTokenParser.
   *
   * @param string $extSTSResponse The ext STS response from SharePoint.
   *
   * @return \Myriad\SharePoint\Auth\SharePointOnline\BinarySecurityTokenParser
   */
  public function getBinarySecurityTokenParser($extSTSResponse) {
    return new BinarySecurityTokenParser($extSTSResponse);
  }

  /**
   * Creates a new token.
   *
   * @param string $accessToken The token used to access resources on sharepoint.
   * @param string $refreshToken The token used to refresh the access token.
   * @param string $notBefore The access token shouldn't be used for this.
   * @param string $expiresOn The time when the access token expires.
   * @param string $realm The realm to authenticate to.
   *
   * @return Contracts\Models\Token
   */
  public function createToken(
    $accessToken,
    $refreshToken,
    $notBefore,
    $expiresOn,
    $realm
  ) {
      return new Token($accessToken, $refreshToken, $notBefore, $expiresOn, $realm);
  }
}