<?php namespace Myriad\SharePoint;

/**
 * Class Configuration represents the configuration for the SharePoint client.
 *
 * @author David Kanenwisher
 * @package Myriad\SharePoint
 */
class Configuration implements Contracts\Configuration {

  /**
   * @var array Holds the configuration data.
   */
  private $config;

  /**
   * Creates a new object.
   *
   * @param array $config Holds the configuration data.
   */
  public function __construct(array $config) {
    $this->config = $config;
  }

  /**
   * Returns the subsite.
   *
   * @return string
   */
  public function getSubSite() {
    return $this->config['sub_site'];
  }

  /**
   * Returns the tenant.
   *
   * @return string
   */
  public function getTenant() {
    return $this->config['tenant'];
  }

  /**
   * Returns the OAuth2 ClientID.
   *
   * @return string
   */
  public function getOAuth2ClientID() {
    return $this->config['oauth2']['client_id'];
  }

  /**
   * Returns the OAth2 Client Secret.
   *
   * @return string
   */
  public function getOAuth2ClientSecret() {
    return $this->config['oauth2']['client_secret'];
  }

  /**
   * Returns the Oauth2 Redirect URI.
   *
   * @return string
   */
  public function getOAuth2RedirectUri() {
    return $this->config['oauth2']['redirect_uri'];
  }

  /**
   * @return string
   */
  public function getOAuth2TokenUrl() {
    return $this->config['oauth2']['token_url'];
  }

  /**
   * Returns the OAuth2 Scope.
   *
   * @return string
   */
  public function getOAuth2Scope() {
    return $this->config['oauth2']['scope'];
  }

  /**
   * Returns the username.
   *
   * @return string
   */
  public function getUsername() {
    return $this->config['username'];
  }

  /**
   * Returns the password.
   *
   * @return string
   */
  public function getPassword() {
    return $this->config['password'];
  }
}
