<?php namespace Myriad\SharePoint\Contracts\Auth\SharePointOnline;

use Myriad\SharePoint\Auth\SharePointOnline\RealmFinder;
use Myriad\SharePoint\Contracts\Models\Token;

/**
 * Interface Operations defines operations that have to be performed during SharePoint
 * authentication.
 *
 * @author David Kanenwisher
 * @package Myriad\SharePoint\Contracts\Auth\SharePointOnline
 */
interface Operations {

  /**
   * Returns an AuthForm.
   *
   * @param \DomXPath $htmlClaimForm The form required in order to request a claim.
   *
   * @return \Myriad\SharePoint\Auth\SharePointOnline\AuthForm
   */
  public function getAuthForm(\DomXPath $htmlClaimForm);

  /**
   * Returns a CodeFinder.
   *
   * @param string $locationHeader The location header.
   *
   * @return \Myriad\SharePoint\Auth\SharePointOnline\CodeFinder
   */
  public function getCodeFinder($locationHeader);

  /**
   * Returns a HtmlToXpath object.
   *
   * @param string $html The HTML string to convert to an XPath object.
   *
   * @return \Myriad\SharePoint\Auth\SharePointOnline\HtmlToXpath
   */
  public function getHtmlToXpath($html);

  /**
   * Returns a RealmFinder.
   *
   * @param string $authenticationHeader The authentication header.
   *
   * @return RealmFinder
   */
  public function getRealmFinder($authenticationHeader);

  /**
   * Returns a BinarySecurityTokenParser.
   *
   * @param string $extSTSResponse The ext STS response from SharePoint.
   *
   * @return \Myriad\SharePoint\Auth\SharePointOnline\BinarySecurityTokenParser
   */
  public function getBinarySecurityTokenParser($extSTSResponse);

  /**
   * Creates a new token.
   *
   * @param string $accessToken The token used to access resources on sharepoint.
   * @param string $refreshToken The token used to refresh the access token.
   * @param string $notBefore The access token shouldn't be used for this.
   * @param string $expiresOn The time when the access token expires.
   * @param string $realm The realm to authenticate to.
   *
   * @return Token
   */
  public function createToken(
    $accessToken,
    $refreshToken,
    $notBefore,
    $expiresOn,
    $realm
  );
}