<?php namespace Myriad\SharePoint\Contracts;

use Myriad\SharePoint\Contracts\Models\Token;

/**
 * Class Connection is responsible for communicating with SharePoint.
 *
 * @author David Kanenwisher
 * @package Myriad\SharePoint\Contracts
 */
interface Connection {

  /**
   * Creates a new object.
   *
   * @param Tenant $tenant The name of the tenant.
   * @param Token $token A SharePointOnline Token.
   * @param \GuzzleHttp\Client $guzzle The HTTP client used to talk to SharePointOnline.
   * @param \Myriad\SharePoint\Contracts\Configuration $config The SharePoint configuration.
   * @param string $siteUrl The URL of the site.
   */
  public function __construct(Tenant $tenant, Token $token, \GuzzleHttp\Client $guzzle, Configuration $config, $siteUrl);

  /**
   * Returns the access token.
   *
   * @return string
   */
  public function getAccessToken();

  /**
   * Returns the refresh token.
   *
   * @return string
   */
  public function getRefreshToken();

  /**
   * Returns the expires on time.
   *
   * @return string
   */
  public function getExpiresOn();

  /**
   * Make a get request to SharePointOnline.
   *
   * @param string $resource The resource to request.
   * @param string $site The SharePoint Online site to make the request to.
   *
   * @return \GuzzleHttp\Message\Response
   */
  public function get($resource, $site = '');

  /**
   * Whether or not the token is authenticated.
   *
   * @return bool
   */
  public function isAuthenticated();

  /**
   * Refreshes the access token.
   *
   * @return bool
   */
  public function refreshAccessToken();

  /**
   * Make a request to the SharePointOnline search API.
   *
   * @param string $url The url to append to the search request.
   *
   * @return \GuzzleHttp\Message\Response
   */
  public function search($url);
}