<?php namespace Myriad\SharePoint\Contracts;

use Myriad\SharePoint\Contracts\Models\CurrentUser;

/**
 * Interface Gateway is responsible for making requests to SharePointOnline.
 *
 * @author David Kanenwisher
 * @package Myriad\SharePoint\Contracts
 */
interface Gateway {

  /**
   * Create a new object.
   * @param \Myriad\SharePoint\Contracts\Connection $connection An authenticated connection to SharePointOnline.
   */
  public function __construct(Connection $connection);

  /**
   * Retrieves information about the currently authenticated user from SharePointOnline.
   *
   * @return CurrentUser
   */
  public function getCurrentUser();

  /**
   * Whether or not the token is authenticated.
   *
   * @return bool
   */
  public function isAuthenticated();

  /**
   * Get the access token that this gateway is using to make requests.
   *
   * @return string
   */
  public function getAccessToken();

  /**
   * Returns the user's refresh token.
   *
   * @return string
   */
  public function getRefreshToken();

  /**
   * Returns the user's expires on time.
   *
   * @return string
   */
  public function getExpiresOn();

  /**
   * Refreshes the access token.
   *
   * @return bool
   */
  public function refreshAccessToken();

  /**
   * Make a get request to SharePointOnline.
   *
   * @param string $resource The resource to request.
   * @param string $site The SharePoint Online site to make the request to.
   *
   * @return \GuzzleHttp\Message\Response
   */
  public function get($resource, $site = '');

  /**
   * Make a request to the SharePointOnline search API.
   *
   * @param string $url The url to append to the search request.
   *
   * @return \GuzzleHttp\Message\Response
   */
  public function search($url);
}