<?php namespace Myriad\SharePoint\Contracts\Models;

use Illuminate\Contracts\Auth\Authenticatable;

/**
 * Interface User represents the user returned by SharePoint and the operations they can perform.
 *
 * @author David Kanenwisher
 * @package Myriad\Sharepoint\Contracts\Models
 */
interface AuthenticatableUser extends Authenticatable {

  /**
   * Whether or not the user is authenticated.
   *
   * @return bool
   */
  public function isAuthenticated();

  /**
   * The user's e-mail address.
   *
   * @return string
   */
  public function getEmailAddress();

  /**
   * The user's name.
   *
   * @return string
   */
  public function getName();

  /**
   * The user's access token.
   *
   * @return string
   */
  public function getAccessToken();

  /**
   * Returns the user's refresh token.
   *
   * @return string
   */
  public function getRefreshToken();

  /**
   * Returns the user's expires in time.
   *
   * @return string
   */
  public function getExpiresOn();

  /**
   * Refreshes the user's access token.
   *
   * @return bool
   */
  public function refreshAccessToken();

  /**
   * Make a get request to SharePointOnline.
   *
   * @param string $resource The resource to request.
   * @param string $site The SharePoint Online site to make the request to.
   *
   * @return \GuzzleHttp\Message\Response
   */
  public function get($resource, $site = '');

  /**
   * Make a request to the SharePointOnline search API.
   *
   * @param string $url The url to append to the search request.
   * @return \GuzzleHttp\Message\Response
   * @throws \Exception
   */
  public function search($url);
}