<?php namespace Myriad\SharePoint\Contracts\Models;

use Myriad\Sharepoint\Contracts;

/**
 * Interface Token represents tokens returned from SharePoint.
 *
 * @author David Kanenwisher
 * @package Myriad\Sharepoint\Contracts\Models
 */
interface Token {

  /**
   * Creates a new token.
   *
   * @param string $accessToken The token used to access resources on sharepoint.
   * @param string $refreshToken The token used to refresh the access token.
   * @param string $notBefore The access token shouldn't be used for this.
   * @param string $expiresOn The time when the access token expires.
   * @param string $realm The realm to authenticate to.
   */
  public function __construct(
    $accessToken,
    $refreshToken,
    $notBefore,
    $expiresOn,
    $realm
  );

  /**
   * Whether or not the object is valid.
   *
   * @return bool
   */
  public function isValid();

  /**
   * Returns the access token.
   *
   * @return string
   */
  public function getAccessToken();

  /**
   * Returns the refresh token.
   *
   * @return string
   */
  public function getRefreshToken();

  /**
   * Returns the expires On time.
   *
   * @return string
   */
  public function getExpiresOn();


  /**
   * Returns the realm.
   *
   * @return string
   */
  public function getRealm();
}