<?php namespace Myriad\SharePoint\Models;

/**
 * Class CurrentUser holds the data returned from SharePointOnline for the current user.
 *
 * @author David Kanenwisher
 * @package Myriad\SharePoint\Models
 */
class CurrentUser implements \Myriad\SharePoint\Contracts\Models\CurrentUser {

  /**
   * @var string The user's e-mail address.
   */
  private $emailAddress;

  /**
   * @var string The user's name.
   */
  private $name;

  /**
   * @var string
   */
  private $loginName;

  /**
   * Creates a new object.
   *
   * @param string $name The user's name.
   * @param string $emailAddress The user's e-mail address.
   * @param string $loginName The LoginName string returned from SharePoint Online.
   */
  public function __construct($name, $emailAddress, $loginName) {
    $this->name = $name;
    $this->emailAddress = $emailAddress;
    $this->loginName = $loginName;
  }

  /**
   * Return's the user's login name.
   *
   * @return string
   */
  private function getLoginName() {
    return $this->loginName;
  }

  /**
   * Returns the e-mail address of the current user.
   *
   * @return string
   */
  public function getEmailAddress() {
    return $this->emailAddress;
  }

  /**
   * Return's the user's name.
   *
   * @return string
   */
  public function getName() {
    return $this->name;
  }

  /**
   * Returns the username the user uses to login to SharePoint Online.
   *
   * @return string
   */
  public function getUsername() {
    $loginName = $this->getLoginName();

    return explode("|", $loginName)[2];
  }
}