<?php namespace Myriad\SharePoint\Models\Token;

use Myriad\SharePoint\Contracts;

/**
 * Class Token represents a token returned by SharePointOnline.
 *
 * @author David Kanenwisher
 * @package Myriad\SharePoint\Model
 */
class Token implements Contracts\Models\Token {

  /**
   * @var string The token used to access resources on SharePoint.
   */
  private $accessToken;

  /**
   * @var string The token used to refresh the access token.
   */
  private $refreshToken;

  /**
   * @var string The access token shouldn't be used before this time.
   */
  private $notBefore;

  /**
   * @var string The time when the access token expires.
   */
  private $expiresOn;

  /**
   * @var string The realm to use when authenticating or refreshing the token.
   */
  private $realm;

  /**
   * Creates a new token.
   *
   * @param string $accessToken The token used to access resources on SharePoint.
   * @param string $refreshToken The token used to refresh the access token.
   * @param string $notBefore The access token shouldn't be used before this time.
   * @param string $expiresOn The time when the access token expires.
   * @param string $realm The realm to use when authenticating or refreshing the token.
   */
  public function __construct(
    $accessToken,
    $refreshToken,
    $notBefore,
    $expiresOn,
    $realm
  ) {
    $this->accessToken = $accessToken;
    $this->refreshToken = $refreshToken;
    $this->notBefore = $notBefore;
    $this->expiresOn = $expiresOn;
    $this->realm = $realm;
  }


  /**
   * Whether or not the object is valid.
   *
   * @return bool
   */
  public function isValid() {
    return (strlen($this->accessToken) > 0);
  }

  /**
   * Returns the access token.
   *
   * @return string
   */
  public function getAccessToken() {
    return $this->accessToken;
  }

  /**
   * Returns the refresh token.
   *
   * @return string
   */
  public function getRefreshToken() {
    return $this->refreshToken;
  }

  /**
   * Returns the expires on time.
   *
   * @return string
   */
  public function getExpiresOn() {
    return $this->expiresOn;
  }

  /**
   * Returns the realm.
   *
   * @return string
   */
  public function getRealm() {
    return $this->realm;
  }
}