<?php namespace Myriad\SharePoint;

use Illuminate\Support\ServiceProvider;
use GuzzleHttp\Subscriber\Retry\RetrySubscriber;

/**
 * Class SharePointServiceProvider makes SharePoint available to any frameworks that support the ServiceProvider
 * interface.
 *
 * @author David Kanenwisher
 * @package Myriad\SharePoint
 */
class SharePointServiceProvider extends ServiceProvider {

  /**
   * Indicates if loading of the provider is deferred.
   *
   * @var bool
   */
  protected $defer = true;

  /**
   * Perform post-registration booting of services.
   *
   * @return void
   */
  public function boot() {
    $this->publishes([__DIR__ . '/../config/sharepoint.php' => config_path('sharepoint.php')]);
  }

  /**
   * Register the service provider.
   *
   * @return void
   */
  public function register() {
    $this->mergeConfigFrom(__DIR__ . '/../config/sharepoint.php', 'sharepoint');

    $this->registerSharepoint();

    $this->app->alias('sharepoint', 'Myriad\SharePoint\Contracts\SharePointClient');
    $this->app->alias('sharepoint', 'Myriad\SharePoint\SharePointClient');
  }

  /**
   * Register the SharePointClient.
   */
  private function registerSharepoint() {
    $this->app->singleton('sharepoint', function ($app) {
    // Retry 500 and 503 responses
      $retry = new RetrySubscriber([
        'filter' => RetrySubscriber::createStatusFilter()
      ]);

      $client = $app['\GuzzleHttp\Client'];
      $client->getEmitter()->attach($retry);
      return new SharePointClient(
        $app['\Myriad\SharePoint\ConfigurationFactory']->create(config('sharepoint')),
        $client,
        $app['\Myriad\SharePoint\Auth\SharePointOnline\Operations'],
        $app['log']
      );
    });
  }

  /**
   * Get the services provided by the provider.
   *
   * @return array
   */
  public function provides() {
    return ['sharepoint', 'Myriad\SharePoint\Contracts\SharePointClient', 'Myriad\SharePoint\SharePointClient'];
  }
}