<?php

namespace Myriad\SharePoint\Tests\Integration;

use Myriad\SharePoint\Tests\TestCase;
use Myriad\SharePoint\Auth\AzureADAuthenticator;
use GuzzleHttp\Client;
use Myriad\SharePoint\Models\Token\Token;
use Myriad\SharePoint\ConfigurationFactory;
use GuzzleHttp\Subscriber\Retry\RetrySubscriber;
use Myriad\SharePoint\SharePointClient;
use Myriad\SharePoint\Auth\SharePointOnline\Operations;
use Myriad\SharePoint\Tests\TestLogger;
use Myriad\SharePoint\Models\AuthenticatedUser;

class AzureADAuthenticatorTest extends TestCase {

  private $authenticator;
  private $guzzle;
  private $config;
  private $username;
  private $password;

  public function setUp() {
    $rawConfig = include(__DIR__.'/test_config.php');
    $this->config = (new ConfigurationFactory)->create($rawConfig);
    $this->username = 
    $this->username = $rawConfig['test']['username'] . $rawConfig['user_domain'];
    $this->password = $rawConfig['test']['password'];
    $this->guzzle = new Client();
    $this->authenticator = new AzureADAuthenticator(
      $this->guzzle,
      $this->config,
      $this->username,
      $this->password
    );
  }
  
  public function testGetAccessTokenSucceeds() {
    $result = $this->authenticator->getAccessToken();
    $this->assertNotNull($result);
    $this->assertInstanceOf(Token::class, $result);
  }

  public function testRefreshTokenSucceeds() {
    $result = $this->authenticator->getAccessToken();
  }

  public function testSharepointClientGetUser() {
    $sharepoint = $this->createSharepointClient();

    $user = $sharepoint->getUser($this->username, $this->password);
    $this->assertNotnull($user);
    $this->assertInstanceOf(AuthenticatedUser::class, $user);
  }

  public function testRefreshAccessToken() {
    $sharepoint = $this->createSharepointClient();

    $user = $sharepoint->getUser($this->username, $this->password);
    $success = $user->refreshAccessToken();
    $this->assertTrue($success);
  }

  private function createSharepointClient() {
    $retry = new RetrySubscriber([
      'filter' => RetrySubscriber::createStatusFilter()
    ]);

    $guzzle = new Client();
    $guzzle->getEmitter()->attach($retry);
    return new SharePointClient( $this->config, $guzzle, new Operations(), new TestLogger());
  }
}
