<?php namespace Myriad\SharePoint\Tests\Unit\Models;

use Myriad\SharePoint\Models\AuthenticatedUser;
use Myriad\SharePoint\Tests\TestCase;

/**
 * Class AuthenticatedUserTest verifies that the AuthenticatedUser works as expected.
 *
 * @author David Kanenwisher
 * @package Myriad\SharePoint\Tests
 */
class AuthenticatedUserTest extends TestCase {

  /**
   * @var AuthenticatedUser The user object to test.
   */
  private $object;

  /**
   * @var \Mockery::Mock A mock SharePointOnlineGateway.
   */
  private $gateway;

  /**
   * Prepeares the AuthenticatedUser for testing.
   *
   * @return \Myriad\SharePoint\Models\AuthenticatedUser
   */
  private function createTestObject() {
    $this->gateway = $this->mock('\Myriad\SharePoint\SharePointOnlineGateway');

    $this->object = new AuthenticatedUser($this->gateway);

    return $this->object;
  }

  /**
   * Clean up after a test runs.
   *
   * @eturn void
   */
  public function tearDown() {
    parent::tearDown();

    $this->object = null;
    $this->gateway = null;
  }

  /**
   * Verify that an AuthenticatedUser is in fact authenticated.
   *
   * @return void
   */
  public function testThatUserIsAuthenticated() {
    $object = $this->createTestObject();

    $this->gateway->shouldReceive('isAuthenticated')->andReturn(true);

    $this->assertTrue($object->isAuthenticated(), "Should be authenticated, if not check any changes made to the Gateway, Connection or Token.");

  }

  /**
   * Verify that the user's e-mail address is returned.
   *
   * @return void
   */
  public function testThatAnAuthenticatedUserHasAnEmailAddress() {
    $object = $this->createTestObject();

    $currentUser = $this->mock('\Myriad\SharePoint\Models\CurrentUser');
    $emailAddress  = 'test@example.com';
    $name = "tester";
    $currentUser->shouldReceive('getEmailAddress')->andReturn($emailAddress);
    $currentUser->shouldReceive('getName')->andReturn($name);

    $this->gateway->shouldReceive('getCurrentUser')->andReturn($currentUser);

    $this->assertEquals($object->getEmailAddress(), $emailAddress);
  }
}
