<?php namespace Myriad\SharePoint\Tests\Unit\Models\Token;

use Myriad\SharePoint\Models\Token\AccessTokenConverter;
use Myriad\SharePoint\Tests\TestCase;

/**
 * Class AccessTokenConverterTest verifies that the tokens converter works correctly.
 *
 * @author David Kanenwisher
 * @package Myriad\SharePoint\Tests\Models\Token
 */
class AccessTokenConverterTest extends TestCase {

  /**
   * @param $path
   *
   * @return string
   */
  private function loadToken($path) {
    return file_get_contents(__DIR__ . '/../../' . $path);
  }

  /**
   * @return string
   */
  private function loadAccessToken() {
    $token = $this->loadToken('/sharePointClientTest/accesstoken.txt');

    return $token;
  }

  /**
   * @return string
   */
  private function loadRefreshToken() {
    $token = $this->loadToken('/sharePointClientTest/refreshtoken.txt');

    return $token;
  }

  /**
   * Verify the a valid token can be converted.
   */
  public function testConvertAValidToken() {
    $accessToken = $this->loadAccessToken();
    $refreshToken = $this->loadRefreshToken();

    $converter = new AccessTokenConverter($accessToken, $refreshToken);

    $token = $converter->convert();

    $this->assertEquals($accessToken, $token->getAccessToken());
    $this->assertEquals($refreshToken, $token->getRefreshToken());
    $this->assertEquals('7c2ea940-749e-40da-a226-d265e4f6914b', $token->getRealm());
  }
}
