<?php namespace Myriad\SharePoint\Tests\Unit;

use Myriad\SharePoint\Models\Token\Token;
use Myriad\SharePoint\SharePointOnlineConnection;
use Myriad\SharePoint\Tenant;
use Myriad\SharePoint\Tests\TestCase;

/**
 * Class SharePointOnlineConnectionTest verifies the class is working correctly.
 *
 * @author David Kanenwsiher
 * @package Myriad\SharePoint\Tests
 */
class SharePointOnlineConnectionTest extends TestCase {

  /**
   * @var SharePointOnlineConnectionTest A SharePointOnline connection.
   */
  private $object;

  /**
   * @var \Myriad\SharePoint\Contracts\Models\Token A SharePointOnline token.
   */
  private $token;

  /**
   * @var \Mockery::Mock A mock guzzle client.
   */
  private $guzzle;

  /**
   * @var \Myriad\SharePoint\Contracts\Tenant A Tenant of SharePointOnline.
   */
  private $tenant;

  /**
   * Clean up after test.
   */
  public function tearDown() {
    parent::tearDown();

    $this->object = null;
    $this->token = null;
    $this->guzzle = null;
    $this->tenant = null;
    $this->configuration = null;
  }

  /**
   * Creates an SharePointOnilneConnection to test with.
   *
   * @return \Myriad\SharePoint\SharePointOnlineConnection
   */
  private function createTestObject() {
    $this->tenant = new Tenant('test');

    $this->configuration = $this->mock('Myriad\SharePoint\Contracts\Configuration');

    $this->guzzle = $this->mock('\GuzzleHttp\Client');

    $this->token = new Token('accessToken', 'refreshToken', 'notBefore', 'expiresOn', 'realm');

    $this->object = new SharePointOnlineConnection($this->tenant, $this->token, $this->guzzle, $this->configuration, "");

    return $this->object;
  }

  /**
   * Verify that the object can be created correctly.
   *
   * @return void
   */
  public function testCreation() {
    $object = $this->createTestObject();
    $token = $this->token;

    $this->assertEquals($token->getAccessToken(), $object->getAccessToken());
    $this->assertEquals($token->getRefreshToken(), $object->getRefreshToken());
    $this->assertTrue($object->isAuthenticated(), "The connection must be authenticated, did something change in the Token?");
  }

  public function testGet() {
    $object = $this->createTestObject();
    $response = $this->mock('\GuzzleHttp\Message\Response');
    $this->guzzle->shouldReceive('get')->once()->andReturn($response);

    $this->assertEquals($object->get("resource"), $response);
  }
}
