<?php namespace Myriad\SharePoint\Tests\Unit;

use Myriad\SharePoint\SharePointOnlineGateway;
use Myriad\SharePoint\Tests\TestCase;

/**
 * Class SharePointOnlineGatewayTest verifies the SharePointOnlineGateway works as expected.
 *
 * @author David Kanenwisher
 * @package Myriad\SharePoint\Tests
 */
class SharePointOnlineGatewayTest extends TestCase {

  private $connection;

  /**
   * Clean up after a test.
   *
   * @return void
   */
  public function tearDown() {
    $this->connection = null;

    \Mockery::close();
  }

  /**
   * Creates a SharePointOnlineGateway object to test with.
   *
   * @return \Myriad\SharePoint\SharePointOnlineGateway
   */
  private function createTestObject() {
    $this->connection = $this->mock('\Myriad\SharePoint\SharePointOnlineConnection');

    $object = new SharePointOnlineGateway($this->connection);

    return $object;
  }

  /**
   * Verify that the Gateway is authenticated when it's provided an authenticated connection.
   *
   * @return void
   */
  public function testConnectionReturnsIsAuthenticatedAfterCreation() {
    $object = $this->createTestObject();
    $this->connection->shouldReceive('isAuthenticated')->andReturn(true);

    $this->assertTrue($object->isAuthenticated(), "The Gateway should be authenticated, did something changed in the connection?");
  }

  /**
   * Verify that an authenticated connection returns the CurrentUser when requested.
   *
   * @return void
   */
  public function testConnectionReturnsCurrentUserWhenAuthenticated() {
    $object = $this->createTestObject();

    $response = $this->mock('\GuzzleHttp\Message\Response');
    $currentUsersEmailAddress = "test@example.com";
    $currentUsersName = "Randolph Bitters";
    $response->shouldReceive('json')->andReturn(['d' => ['Email' => $currentUsersEmailAddress, 'Title' => $currentUsersName]]);
    $this->connection->shouldReceive('get')->andReturn($response);

    $this->assertEquals($object->getCurrentUser()->getEmailAddress(), $currentUsersEmailAddress);
    $this->assertEquals($object->getCurrentUser()->getName(), $currentUsersName);
  }
}
